<?php
/**
 * Plugin Name: Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
 * Plugin URI:  https://wpwebelite.com/
 * Description: Adds Multi Language Characters Support for pdf vouchers.
 * Version: 1.0.0
 * Author: WPWeb
 * Author URI: https://wpwebelite.com/
 * Text Domain: eddvoucherpf
 * Domain Path: languages 
 * 
 * 
 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
 * @category Core
 * @author WPWeb
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Basic plugin definitions
 * 
 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
 * @since 1.0.0
 */
if( !defined( 'EDD_VOU_PF_PLUGIN_VERSION' ) ) {
	define( 'EDD_VOU_PF_PLUGIN_VERSION', '1.0.0' ); //Plugin version number
}
if( !defined( 'EDD_VOU_PF_DIR' ) ) {
	define( 'EDD_VOU_PF_DIR', dirname( __FILE__ ) ); // plugin dir
}
if( !defined( 'EDD_VOU_PF_URL' ) ) {
	define( 'EDD_VOU_PF_URL', plugin_dir_url( __FILE__ ) ); // plugin url
}
if( !defined( 'EDD_VOU_PF_ADMIN' ) ) {
	define( 'EDD_VOU_PF_ADMIN', EDD_VOU_PF_DIR . '/includes/admin' ); // plugin admin dir
}
if( !defined( 'EDD_VOU_PF_PLUGIN_BASENAME' ) ) {
	define( 'EDD_VOU_PF_PLUGIN_BASENAME', basename( EDD_VOU_PF_DIR ) ); //Plugin base name
}
if ( ! defined( 'EDD_VOU_PF_PLUGIN_KEY' ) ) {
	define( 'EDD_VOU_PF_PLUGIN_KEY', 'eddpfvouchers' );
}

/**
 * Admin notices
 *
 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
 * @since 1.0.0
*/
function edd_vou_pf_admin_notices() {
	if( !defined( EDD_VOU_DIR ) ) {	
		echo '<div class="error">';
		echo "<p><strong>" . __( ' Easy Digital Downloads PDF Vouchers needs to be activated to be able to use the Easy Digital Downloads PDF Voucher PDF Fonts.', 'eddvoucherpf' ) . "</strong></p>";
		echo '</div>';
	}
}

/**
 * Check WooCommerce PDF Vouchers Plugin
 *
 * Handles to check Easy Digital Downloads plugin
 * if not activated then deactivate our plugin
 *
 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
 * @since 1.0.0
 */
function edd_vou_pf_check_activation() {

	// Check if constants are defined and PDF Vouchers plugin is active
	if ( !defined('EDD_VOU_PLUGIN_BASENAME') && !defined('EDD_VOU_PLUGIN_BASE_FILENAME') 
		&& !is_plugin_active('easy-digital-downloads/easy-digital-downloads.php') ) {

		// is this plugin active?
		if( is_plugin_active( plugin_basename( __FILE__ ) ) ) {
			// deactivate the plugin
	 		deactivate_plugins( plugin_basename( __FILE__ ) );
	 		// unset activation notice
	 		unset( $_GET[ 'activate' ] );
	 		// display notice
	 		add_action( 'admin_notices', 'edd_vou_pf_admin_notices' );
		}
	}
}
//Check Easy Digital Downloads plugin is Activated or not
add_action( 'admin_init', 'edd_vou_pf_check_activation' );

/**
 * Deactivation Hook
 * 
 * Register plugin deactivation hook.
 * 
 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
 *  @since 1.0.3
 */
register_deactivation_hook( __FILE__, 'edd_vou_pf_uninstall' );

/**
 * Plugin Setup (On Deactivation)
 * 
 * Delete  plugin options.
 * 
 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
 * @since 1.0.3
 */
function edd_vou_pf_uninstall() {
	global $wpdb;

	// delete global settings
	delete_option( 'eddpdf_font' );
	delete_option( 'edd_custom_font_name_option' );

	// post meta table
	$tableName = $wpdb->prefix . 'postmeta';

	// Delete metaboxes
	$wpdb->query( "DELETE FROM `{$tableName}` WHERE meta_key = '_edd_vou_pdf_font' OR meta_key = '_edd_vou_pdf_template_custom_font'" );
}

/**
 * Load Text Domain
 * 
 * This gets the plugin ready for translation.
 * 
 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
 * @since 1.0.0
 */
function edd_vou_pf_load_text_domain() {
	
	// Set filter for plugin's languages directory
	$edd_vou_pf_lang_dir	= dirname( plugin_basename( __FILE__ ) ) . '/languages/';
	$edd_vou_pf_lang_dir	= apply_filters( 'edd_vou_pf_languages_directory', $edd_vou_pf_lang_dir );
	
	// Traditional WordPress plugin locale filter
	$locale	= apply_filters( 'plugin_locale',  get_locale(), 'eddvoucher' );
	$mofile	= sprintf( '%1$s-%2$s.mo', 'eddvoucherpf', $locale );
	
	// Setup paths to current locale file
	$mofile_local	= $edd_vou_pf_lang_dir . $mofile;
	$mofile_global	= WP_LANG_DIR . '/' . EDD_VOU_PF_PLUGIN_BASENAME . '/' . $mofile;
	
	if ( file_exists( $mofile_global ) ) { // Look in global /wp-content/languages/woocommerce-pdf-vouchers-pdf-fonts folder
		load_textdomain( 'eddvoucherpf', $mofile_global );
	} elseif ( file_exists( $mofile_local ) ) { // Look in local /wp-content/plugins/woocommerce-pdf-vouchers-pdf-fonts/languages/ folder
		load_textdomain( 'eddvoucherpf', $mofile_local );
	} else { // Load the default language files
		load_plugin_textdomain( 'eddvoucherpf', false, $edd_vou_pf_lang_dir );
	}
}

//add action to load plugin
add_action( 'plugins_loaded', 'edd_vou_pf_plugin_loaded', 999 );

/**
 * Load Plugin
 * 
 * Handles to load plugin after
 * dependent plugin is loaded
 * successfully
 * 
 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
 * @since 1.0.0
 */
function edd_vou_pf_plugin_loaded() {

	//check Woocommerce is activated or not
	if( class_exists( 'Easy_Digital_Downloads' ) ) {
		
		// load first plugin text domain
		edd_vou_pf_load_text_domain();
		
		global $edd_vou_pf_admin, $edd_vou_pf_scripts;
		
		//Admin Pages Class for admin side
		require_once( EDD_VOU_PF_ADMIN . '/class-edd-vou-pf-admin.php' );
		$edd_vou_pf_admin = new EDD_Vou_Pf_Admin();
		$edd_vou_pf_admin->add_hooks();

		//Script Pages Class for admin side
		require_once( EDD_VOU_PF_DIR . '/includes/class-edd-vou-pf-scripts.php' );
		$edd_vou_pf_scripts = new EDD_Vou_Pf_Script();
		$edd_vou_pf_scripts->add_hooks();
		
	} //end if to check class Woocommerce is exist or not

	if( defined( 'WPWEB_UPD_DIR' ) ) {
	
		// Plugin updates
		wpweb_queue_update( plugin_basename( __FILE__ ), EDD_VOU_PF_PLUGIN_KEY );

		include_once( WPWEB_UPD_DIR . '/updates/class-plugin-update-checker.php' );
		
		$WpwebEddVouchersPdfFontsUpdateChecker = new WpwebPluginUpdateChecker(
			WPWEB_UPD_DOMAIN . '/Updates/EDDVouchersPdfFonts/info.json',
			__FILE__,
			EDD_VOU_PF_PLUGIN_KEY
		);
	}
	
	
} //end if to check plugin loaded is called or not