<?php
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Admin Class
 *
 * Handles generic Admin functionality and AJAX requests.
 *
 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
 * @since 1.0.0
 */
class EDD_Vou_Pf_Admin {
	
	var $model;

	public function __construct() {
		global $edd_vou_model;		
		$this->model = $edd_vou_model;
	}
	
	/**
	 * Add Pdf fonts settings
	 * 
	 * Handle to add more pdf fonts to support all languages character
	 *
	 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	function edd_vou_pf_settings( $edd_vou_settings ) {

		// define all pdf fonts
		$all_pdf_fonts = array(
					''		=> esc_html__( 'Please Select', 'eddvoucherpf' ),			
			'courier' 		=> 'Courier',
			'courierB' 		=> 'Courier Bold',
			'courierBI' 	=> 'Courier Bold Italic',
			'courierI' 		=> 'Courier Italic',							
			'helveticaB' 	=> 'Helvetica Bold',
			'helveticaBI' 	=> 'Helvetica Bold Italic',
			'helveticaI' 	=> 'Helvetica Italic',
			'times' 		=> 'Times New Roman',
			'timesB' 		=> 'Times New Roman Bold',
			'timesBI' 		=> 'Times New Roman Bold Italic',
			'timesI' 		=> 'Times New Roman Italic',
			'myriad'		=> 'Myriad',
			'symbol' 		=> 'Symbol',							
			'zapfdingbats' 	=> 'Zapf Dingbats',	
			'freeserif'		=> 'freeserif (Suppot most of the languages)',
			'cid0jp'		=> 'cid0jp (Chinese, Korean & Japanese)',
			'custom'		=> 'Custom Font'
		);

		$edd_pdf_settings[] = array(
			'id'		=> 'vou_pdf_font',
			'name'		=> esc_html__( 'Font:', 'eddvoucherpf' ),
			'desc'		=> '<p class="description">'.sprintf(esc_html__( 'Select fonts for character support for PDF voucher. If you select  %s Custom Font %s option then you need to put font in %s wp-content/edd-pdf-vouchers/fonts%s folder.', 'eddvoucherpf' ),'<strong>','</strong>','<code>','</code>').'</p>',
			'type'		=> 'select',
			'options'	=> $all_pdf_fonts,
			'default'	=> 'freeserif',
			'class' 	=> 'edd-pdf-font',
		);
		$edd_pdf_settings[]  = array(
			'id'		=> 'vou_custom_font_name_option',
			'name'		=> esc_html__( 'Custom Font Name', 'eddvoucherpf' ),
			'desc'		=> '<p class="description">'.esc_html__( 'Enter the name of your custom font. Make sure you enter the font name correctly.', 'eddvoucherpf' ).'<p>',
			'type'		=> 'filename',			
			'default'   => '',
			'desc_tip'	=> ''
		);


		// merge settings									
		array_splice( $edd_vou_settings, 9, 0, $edd_pdf_settings ); // splice in at position 2	
		return $edd_vou_settings;
	}
	
	/**
	 * Add Custom select box 	 
	 *
	 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function woo_vou_pf_admin_field_vou_pf_select_box( $field ) {
		
		$defaults = array(
			'title'             => '',
			'disabled'          => false,
			'class'             => '',
			'css'               => '',
			'placeholder'       => '',
			'type'              => 'text',
			'desc_tip'          => false,
			'description'       => '',
			'custom_attributes' => array(),
			'options'           => array(),
		);

		$field = wp_parse_args( $field, $defaults );

		if ( isset( $field['type'] ) && $field['type'] == 'vou_pf_select_box' ) : 
			
			$field_value	= get_option( $field['id'] );
			
			if( empty( $field_value ) ) {
				$field_value	= $field['default'];
			}
			
			?>			
			
			<tr valign="top">
				<th scope="row" class="titledesc">
					<label for="<?php echo esc_attr( $field['id'] ); ?>"><?php echo wp_kses_post( $field['title'] ); ?></label>					
				</th>
				<td class="forminp forminp-text">
					<fieldset>
						<legend class="screen-reader-text"><span><?php echo wp_kses_post( $field['title'] ); ?></span></legend>
						<select id="<?php echo esc_attr( $field['id'] ); ?>" class="select <?php echo esc_attr( $field['class'] ); ?>" title="<?php echo esc_attr( $field['name'] ); ?>" name="<?php echo esc_attr( $field['id'] ); ?>">
						<?php 
							foreach ( (array) $field['options'] as $option_key => $option_value ) :
								if( is_array( $option_value ) ) { ?>
									<optgroup label="<?php echo $option_key; ?>">
										<?php foreach ( $option_value as $second_option_key => $second_option_value ) : ?>
											<option value="<?php echo esc_attr( $second_option_key ); ?>" <?php selected( $second_option_key, esc_attr( $field_value ) ); ?>><?php echo esc_attr( $second_option_value ); ?></option>
										<?php endforeach; ?>
									</optgroup>
								<?php } else { ?>
									<option value="<?php echo esc_attr( $option_key ); ?>" <?php selected( $option_key, esc_attr( $field_value ) ); ?>><?php echo esc_attr( $option_value ); ?></option>
								<?php } ?>
						<?php endforeach; ?>
						</select>
					</fieldset>
					<span class="description"><?php echo $field['desc'];?></span>
				</td>
			</tr><?php
		
		endif;		
	}
	
	/**
	 * Save Custom select box 	 
	 *
	 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function woo_vou_pf_save_vou_pf_select_box( $field ) {

		if ( isset( $_POST[ $field['id'] ] ) ) {
			update_option( $field['id'], $_POST[ $field['id']] );
		}
	}
	
	/**
	 * Change pdf fonts path	 
	 *
	 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function edd_vou_pf_tcpdf_font_path( $tcpdf_fonts_path ) {
	
		global $pdf_template_id;	
		
		// getting character support
		$voucher_char_support = edd_get_option( 'vou_char_support' );
		
		// get font from global setting
		$vou_pdf_font = edd_get_option( 'vou_pdf_font' );
		
		if( !empty($pdf_template_id) ) {
			$prefix = EDD_VOU_META_PREFIX;
			$metaFont = get_post_meta( $pdf_template_id, $prefix . 'pdf_font', true );
			$vou_pdf_font = !empty( $metaFont ) ? $metaFont : $vou_pdf_font;
		}
		
		// check if its selected, yes then chage fonts path to this addon
		if( !empty( $voucher_char_support)  ) {
			
			// if custom font selected then load from wp-content/woocommerce-pdf-vouchers/fonts to prevent loss on update of plugin
			$customFontDir = WP_CONTENT_DIR .'/edd-pdf-vouchers/fonts';
			
			if( $vou_pdf_font == 'custom' && is_dir( $customFontDir )) { 
				$fdir = WP_CONTENT_DIR .'/edd-pdf-vouchers/fonts';
			} else {
				$fdir = realpath( EDD_VOU_PF_DIR.'/includes/tcpdf/fonts' );
			}
			if (substr($fdir, -1) != '/') {
				$fdir .= '/';
			}
			$tcpdf_fonts_path = $fdir;

		}
		return  $tcpdf_fonts_path;
	}
	
	/**
	 * Add metabox for pdf font selection in voucher template
	 *
	 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function edd_vou_pf_add_meta_box(){
		
		$voucher_char_support = edd_get_option( 'vou_char_support' );
		
		if( empty( $voucher_char_support ) || $voucher_char_support == 'no' ) return;
		
		add_meta_box( 'edd_vou_pf_pdf_fonts_meta' ,__( 'Font', 'eddvoucher' ), array( $this, 'edd_vou_pf_pdf_fonts_meta' ), EDD_VOU_POST_TYPE, 'normal', 'low', 1 );
	}
	
	/**
	 * Metabox content for pdf font selection in voucher template
	 *
	 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function edd_vou_pf_pdf_fonts_meta(){
		
		$prefix = EDD_VOU_META_PREFIX;	
		
		// define all pdf fonts
		$all_pdf_fonts = array(
				''				=> __( 'Please Select', 'woovoucherpf' ),
				'General Fonts'		=> array(
					'courier' 		=> 'Courier',
					'courierB' 		=> 'Courier Bold',
					'courierBI' 	=> 'Courier Bold Italic',
					'courierI' 		=> 'Courier Italic',							
					'helveticaB' 	=> 'Helvetica Bold',
					'helveticaBI' 	=> 'Helvetica Bold Italic',
					'helveticaI' 	=> 'Helvetica Italic',
					'times' 		=> 'Times New Roman',
					'timesB' 		=> 'Times New Roman Bold',
					'timesBI' 		=> 'Times New Roman Bold Italic',
					'timesI' 		=> 'Times New Roman Italic',
					'myriad'		=> 'Myriad'
				),
				'Symbolic Fonts'	=> array(
					'symbol' 		=> 'Symbol',							
					'zapfdingbats' 	=> 'Zapf Dingbats',	
				),
				'Persian and Arabic language Fonts' => array(
					'freeserif'		=> 'freeserif (Suppot most of the languages)'
				),
				'CID-0 CJK Fonts'	=> array(								
					'cid0jp'		=> 'cid0jp (Chinese, Korean & Japanese)'
				),
				'custom'			=> __( 'Custom Font', 'woovoucherpf' ),
			);
		
		
		edd_vou_content_begin();

		$this->edd_vou_pf_add_select( array( 'id' => $prefix . 'pdf_font', 'style' => 'width:60%; min-width:200px; float: left;', 'class' => 'regular-text edd-pdf-font-select wc-enhanced-select woo_vou_pdf_font', 'name'=> __( 'Font:', 'eddvoucherpf' ), 'options' => $all_pdf_fonts, 'desc' => sprintf( esc_html__( 'Select fonts for character support for PDF voucher. If you select  %sCustom Font%s option then you need to put font in %swp-content/edd-pdf-vouchers/fonts%s folder.', 'eddvoucherpf' ), '<strong>', '</strong>', '<code>', '</code>'  ) ) );

		edd_vou_add_text( array( 'id' => $prefix . 'pdf_template_custom_font', 'class' => ' edd-pdf-custom-font-input regular-text pdf_template_custom_font', 'name'=> __( 'Custom Font Name:', 'eddvoucherpf' ), 'desc' => __( 'Enter the name of your custom font. Make sure you enter the font name correctly.', 'eddvoucherpf' ), 'field_desc' => '' ) );
		edd_vou_content_end();
		
	}
	
	/**
	 * Show Field Select.
	 *
	 * @param string $field 
	 * @param string $meta 
	 * @since 1.0
	 * @access public
	 */
	function edd_vou_pf_add_select( $args, $echo = true ) {
		
		$html = '';
		
		$new_field = array( 'type' => 'select', 'name' => 'Select Field', 'multiple' => false, 'style' => '' );
		$field = array_merge( $new_field, $args );
		
		$default_meta = isset( $field['default'] ) ? $field['default'] : '';
		
		$meta = edd_vou_meta_value( $field );
		$meta = !empty( $meta ) ? $meta : $default_meta;
		
		if( ! is_array( $meta ) ) {
			$meta = (array) $meta;
		}
		
		$html .= edd_vou_show_field_begin( $field );
		
		$html .= "<select class='edd-vou-meta-select  {$field['class']} ".($field['multiple'] ? 'edd-vou-meta-multiple-select' : 'edd-vou-meta-single-select')."' name='{$field['id']}" . ( $field['multiple'] ? "[]' id='{$field['id']}' multiple='multiple'" : "'" ) . " style='" . esc_attr( $field['style'] ) . "'>";
		
		foreach ( (array) $field['options'] as $option_key => $option_value ) :
			if( is_array( $option_value ) ) {
				$html .= '<optgroup label="'.$option_key.'">';
					foreach ( $option_value as $second_option_key => $second_option_value ) :
						$html .= "<option value='".esc_attr( $second_option_key )."' ".selected( $second_option_key, esc_attr( $meta[0] ), false ).">".esc_attr( $second_option_value )."</option>";
					endforeach;
				$html .= '</optgroup>';
			} else {
				$html .= "<option value='".esc_attr( $option_key )."' ".selected( $option_key, esc_attr( $meta[0] ), false ).">".esc_attr( $option_value )."</option>";
			}
		endforeach;
		
		$html .= "</select>";	
			
		$html .= edd_vou_show_field_end( $field );
		
		if($echo) {
			echo $html;
		} else {
			return $html;
		}
		
	}

	/**
	 * Show text Field.
	 *
	 * @param string $args
	 * @param string $echo 
	 * @since 2.8.2
	 * @access public
	 */
	function woo_vou_pf_add_text( $args, $echo = true ){

		$html = '';
	
		$new_field = array( 'type' => 'text', 'name' => 'Text Field', 'field_desc' => '', 'class' => '' );
		$field = array_merge( $new_field, $args );
		
		$meta = woo_vou_meta_value( $field );
		
		$html .= woo_vou_show_field_begin( $field );
		
		$html .= "<input type='text' class='woo-vou-meta-text {$field['class']}' name='{$field['id']}' id='{$field['id']}' value='{$meta}' />";
		$html .= $field['field_desc'];
		
		$html .= woo_vou_show_field_end( $field );
		
		if($echo) {
			echo $html;
		} else {
			return $html;
		}
		
	}

	
	/**
	 * Save Voucher Meta Content
	 * 
	 * Handles to saving voucher meta on update voucher template post type
	 * 
	 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function edd_vou_pf_save_metadata( $post_id ){
		
		global $post_type;
		
		$prefix = EDD_VOU_META_PREFIX;
		
		$post_type_object = get_post_type_object( $post_type );
		
		// Check for which post type we need to add the meta box
		$pages = array( EDD_VOU_POST_TYPE );
		
		if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )                // Check Autosave
		|| ( ! isset( $_POST['post_ID'] ) || $post_id != $_POST['post_ID'] )        // Check Revision
		|| ( ! in_array( $post_type, $pages ) )              // Check if current post type is supported.
		|| ( ! check_admin_referer( EDD_VOU_PLUGIN_BASENAME, 'at_edd_vou_meta_box_nonce') )      // Check nonce - Security
		|| ( ! current_user_can( $post_type_object->cap->edit_post, $post_id ) ) )       // Check permission
		{
			return $post_id;
		}
		
		//Update Margin Right
		if( isset( $_POST[ $prefix . 'pdf_font' ] ) ) {
			update_post_meta( $post_id, $prefix . 'pdf_font', $_POST[ $prefix . 'pdf_font' ] );
		}

		if( isset( $_POST[ $prefix . 'pdf_template_custom_font' ] ) ) {
			update_post_meta( $post_id, $prefix . 'pdf_template_custom_font', $_POST[ $prefix . 'pdf_template_custom_font' ] );
		}
	}
	
	/**
	 * Add filter to get pdf font
	 *
	 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function edd_vou_pf_generate_fonts( $pdf_font, $template_id = '' ){
		
		global $voucher_template_id;	

		$pdf_template_id = ( !empty($template_id) ) ? $template_id : $voucher_template_id;		
		
		$prefix = EDD_VOU_META_PREFIX;
		
		// getting character support
		$voucher_char_support = edd_get_option( 'vou_char_support' );
		
		if( $voucher_char_support ) { // if charactor support is enable			
			
			// get font from global setting
			$vou_pdf_font	= edd_get_option('vou_pdf_font');			
			
			// if custom font is selected than get font name from custom text box
			if ( $vou_pdf_font == 'custom') {				
				
				$vou_pdf_font = $pdf_font;
				
				if( is_dir(WP_CONTENT_DIR .'/edd-pdf-vouchers/fonts') ){
					$vou_pdf_font = edd_get_option( 'vou_custom_font_name_option' );
				}
			}
				
			if( !empty( $pdf_template_id ) ) { // if template is not empty
				
				// get font from voucher template meta field
				$vou_pdf_font_meta = get_post_meta( $pdf_template_id,$prefix.'pdf_font', true );
				
				// if custom font is selected from voucher template meta field than get font name from custom text box in meta field
				if ( $vou_pdf_font_meta == 'custom') {
					$vou_pdf_font_meta = get_post_meta( $pdf_template_id,$prefix.'pdf_template_custom_font', true );
				}

				if( !empty( $vou_pdf_font_meta ) ) { // if meta value is not empty
					$vou_pdf_font = $vou_pdf_font_meta;
				}
			}
				
			if( !empty( $vou_pdf_font ) ) {
				$pdf_font = $vou_pdf_font;
			}
		}		
		return $pdf_font;
	}
	

	/**
	 * Add filter to validate settings field
	 *
	 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function edd_vou_pf_settings_validate($input){
		
		$input['vou_pdf_font'] = $this->model->edd_vou_escape_slashes_deep( $input['vou_pdf_font'] );
		return $input;
	}
	

	/**
	 * Adding Hooks
	 *
	 * @package Easy Digital Downloads PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function add_hooks() {
		
		// add filter to add more fonts for language support		
		add_filter( 'edd_vou_settings', array( $this, 'edd_vou_pf_settings' ) );

		//add filter to extension settings field
		add_filter( 'edd_settings_extensions-eddvoucher_sanitize', array( $this, 'edd_vou_pf_settings_validate'));

		// To change default font from TCPDF
		add_filter( 'edd_vou_tcpdf_main_font', array( $this, 'edd_vou_pf_generate_fonts' ), 10, 1 );
		
		// Add filter to get pdf font
		add_filter( 'edd_vou_pdf_generate_fonts', array( $this, 'edd_vou_pf_generate_fonts' ), 10, 2 );
		
		add_filter( 'edd_vou_tcpdf_data_font', array( $this, 'edd_vou_pf_generate_fonts' ), 10, 1 );

		// Add metabox for pdf font selection in voucher template
		add_action( 'add_meta_boxes', array( $this, 'edd_vou_pf_add_meta_box' ) );
		
		// Saving voucher meta on update or publish voucher template post type
		add_action( 'save_post', array( $this, 'edd_vou_pf_save_metadata' ) );

		// add filter to change pdf font path
		add_filter( 'edd_vou_tcpdf_fonts_path', array( $this, 'edd_vou_pf_tcpdf_font_path' ) );
		
		/*
		// add action to add custom field (select box with option group)
		add_action( 'woocommerce_admin_field_vou_pf_select_box', array( $this, 'woo_vou_pf_admin_field_vou_pf_select_box' ) );
		
		
		*/
	}
}